@@ -206,6 +206,14 @@ auth_callback (SMBCCTX *context,
       backend->mount_try_again = TRUE;
       g_debug ("auth_callback - kerberos pass\n");
     }
+  else if (backend->mount_try == 1 &&
+           backend->user == NULL &&
+           backend->domain == NULL)
+    {
+      /* Try again if ccache login fails */
+      backend->mount_try_again = TRUE;
+      g_debug ("auth_callback - ccache pass\n");
+    }
   else if (backend->use_anonymous)
     {
       /* Try again if anonymous login fails */
@@ -409,14 +417,11 @@ do_mount (GVfsBackend *backend,
   if (op_backend->default_workgroup != NULL)
     smbc_setWorkgroup (smb_context, op_backend->default_workgroup);
 
-  /* Initial settings:
-   *   - use Kerberos (always)
-   *   - in case of no username specified, try anonymous login
-   */
   smbc_setOptionUseKerberos (smb_context, 1);
   smbc_setOptionFallbackAfterKerberos (smb_context,
                                        op_backend->user != NULL);
   smbc_setOptionNoAutoAnonymousLogin (smb_context, TRUE);
+  smbc_setOptionUseCCache (smb_context, 1);
 
   if (!smbc_init_context (smb_context))
     {
@@ -473,6 +478,12 @@ do_mount (GVfsBackend *backend,
 
   errsv = 0;
 
+  /* If user is not specified, first and second iteration is kerberos resp.
+   * ccache only (this is necessary in order to prevent redundant password
+   * prompts). Consequently, credentials from keyring are tried if available.
+   * Finally, user is prompted over GMountOperation if available. Anonymous is
+   * tried only if explicitely requested over GMountOperation.
+   */
   do
     {
       op_backend->mount_try_again = FALSE;
@@ -500,9 +511,10 @@ do_mount (GVfsBackend *backend,
       /* The first round is Kerberos-only.  Only if this fails do we enable
        * NTLMSSP fallback.
        */
-      if (op_backend->mount_try == 0)
+      if (op_backend->mount_try == 0 &&
+          op_backend->user == NULL)
         {
-          g_debug ("do_mount - after anon, enabling NTLMSSP fallback\n");
+          g_debug ("do_mount - enabling NTLMSSP fallback\n");
           smbc_setOptionFallbackAfterKerberos (op_backend->smb_context, 1);
         }
 
